#########
Abjad API
#########

*************************
Core composition packages
*************************

:py:mod:`agenttools <abjad.tools.agenttools>`
=============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/agenttools/index

   .. toctree::
      :maxdepth: 1

      tools/agenttools/InspectionAgent
      tools/agenttools/IterationAgent
      tools/agenttools/MutationAgent
      tools/agenttools/PersistenceAgent

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/agenttools/InspectionAgent
      tools/agenttools/IterationAgent
      tools/agenttools/MutationAgent
      tools/agenttools/PersistenceAgent

:py:mod:`datastructuretools <abjad.tools.datastructuretools>`
=============================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/datastructuretools/index

   .. toctree::
      :maxdepth: 1

      tools/datastructuretools/TypedCollection

   .. toctree::
      :maxdepth: 1

      tools/datastructuretools/CyclicList
      tools/datastructuretools/CyclicMatrix
      tools/datastructuretools/CyclicPayloadTree
      tools/datastructuretools/CyclicTuple
      tools/datastructuretools/Matrix
      tools/datastructuretools/OrdinalConstant
      tools/datastructuretools/PayloadTree
      tools/datastructuretools/SortedCollection
      tools/datastructuretools/StatalServer
      tools/datastructuretools/StatalServerCursor
      tools/datastructuretools/TreeContainer
      tools/datastructuretools/TreeNode
      tools/datastructuretools/TypedCounter
      tools/datastructuretools/TypedFrozenset
      tools/datastructuretools/TypedList
      tools/datastructuretools/TypedTuple

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/datastructuretools/TypedCollection

   Concrete classes
   ----------------

   .. toctree::

      tools/datastructuretools/CyclicList
      tools/datastructuretools/CyclicMatrix
      tools/datastructuretools/CyclicPayloadTree
      tools/datastructuretools/CyclicTuple
      tools/datastructuretools/Matrix
      tools/datastructuretools/OrdinalConstant
      tools/datastructuretools/PayloadTree
      tools/datastructuretools/SortedCollection
      tools/datastructuretools/StatalServer
      tools/datastructuretools/StatalServerCursor
      tools/datastructuretools/TreeContainer
      tools/datastructuretools/TreeNode
      tools/datastructuretools/TypedCounter
      tools/datastructuretools/TypedFrozenset
      tools/datastructuretools/TypedList
      tools/datastructuretools/TypedTuple

:py:mod:`durationtools <abjad.tools.durationtools>`
===================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/durationtools/index

   .. toctree::
      :maxdepth: 1

      tools/durationtools/Duration
      tools/durationtools/Multiplier
      tools/durationtools/Offset

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/durationtools/Duration
      tools/durationtools/Multiplier
      tools/durationtools/Offset

:py:mod:`indicatortools <abjad.tools.indicatortools>`
=====================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/indicatortools/index

   .. toctree::
      :maxdepth: 1

      tools/indicatortools/Annotation
      tools/indicatortools/Articulation
      tools/indicatortools/BarLine
      tools/indicatortools/BendAfter
      tools/indicatortools/Clef
      tools/indicatortools/ClefInventory
      tools/indicatortools/Dynamic
      tools/indicatortools/IndicatorExpression
      tools/indicatortools/IsAtSoundingPitch
      tools/indicatortools/IsUnpitched
      tools/indicatortools/KeySignature
      tools/indicatortools/LilyPondCommand
      tools/indicatortools/LilyPondComment
      tools/indicatortools/StaffChange
      tools/indicatortools/StemTremolo
      tools/indicatortools/Tempo
      tools/indicatortools/TempoInventory
      tools/indicatortools/TimeSignature

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/indicatortools/Annotation
      tools/indicatortools/Articulation
      tools/indicatortools/BarLine
      tools/indicatortools/BendAfter
      tools/indicatortools/Clef
      tools/indicatortools/ClefInventory
      tools/indicatortools/Dynamic
      tools/indicatortools/IndicatorExpression
      tools/indicatortools/IsAtSoundingPitch
      tools/indicatortools/IsUnpitched
      tools/indicatortools/KeySignature
      tools/indicatortools/LilyPondCommand
      tools/indicatortools/LilyPondComment
      tools/indicatortools/StaffChange
      tools/indicatortools/StemTremolo
      tools/indicatortools/Tempo
      tools/indicatortools/TempoInventory
      tools/indicatortools/TimeSignature

:py:mod:`instrumenttools <abjad.tools.instrumenttools>`
=======================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/instrumenttools/index

   .. toctree::
      :maxdepth: 1

      tools/instrumenttools/Accordion
      tools/instrumenttools/AltoFlute
      tools/instrumenttools/AltoSaxophone
      tools/instrumenttools/AltoTrombone
      tools/instrumenttools/AltoVoice
      tools/instrumenttools/BaritoneSaxophone
      tools/instrumenttools/BaritoneVoice
      tools/instrumenttools/BassClarinet
      tools/instrumenttools/BassFlute
      tools/instrumenttools/BassSaxophone
      tools/instrumenttools/BassTrombone
      tools/instrumenttools/BassVoice
      tools/instrumenttools/Bassoon
      tools/instrumenttools/Cello
      tools/instrumenttools/ClarinetInA
      tools/instrumenttools/ClarinetInBFlat
      tools/instrumenttools/ClarinetInEFlat
      tools/instrumenttools/Contrabass
      tools/instrumenttools/ContrabassClarinet
      tools/instrumenttools/ContrabassFlute
      tools/instrumenttools/ContrabassSaxophone
      tools/instrumenttools/Contrabassoon
      tools/instrumenttools/EnglishHorn
      tools/instrumenttools/Flute
      tools/instrumenttools/FrenchHorn
      tools/instrumenttools/Glockenspiel
      tools/instrumenttools/Guitar
      tools/instrumenttools/Harp
      tools/instrumenttools/Harpsichord
      tools/instrumenttools/Instrument
      tools/instrumenttools/InstrumentInventory
      tools/instrumenttools/InstrumentationSpecifier
      tools/instrumenttools/Marimba
      tools/instrumenttools/MezzoSopranoVoice
      tools/instrumenttools/Oboe
      tools/instrumenttools/Performer
      tools/instrumenttools/PerformerInventory
      tools/instrumenttools/Piano
      tools/instrumenttools/Piccolo
      tools/instrumenttools/SopraninoSaxophone
      tools/instrumenttools/SopranoSaxophone
      tools/instrumenttools/SopranoVoice
      tools/instrumenttools/TenorSaxophone
      tools/instrumenttools/TenorTrombone
      tools/instrumenttools/TenorVoice
      tools/instrumenttools/Trumpet
      tools/instrumenttools/Tuba
      tools/instrumenttools/UntunedPercussion
      tools/instrumenttools/Vibraphone
      tools/instrumenttools/Viola
      tools/instrumenttools/Violin
      tools/instrumenttools/WoodwindFingering
      tools/instrumenttools/Xylophone

   .. toctree::
      :maxdepth: 1

      tools/instrumenttools/iterate_out_of_range_notes_and_chords
      tools/instrumenttools/notes_and_chords_are_in_range
      tools/instrumenttools/notes_and_chords_are_on_expected_clefs
      tools/instrumenttools/transpose_from_sounding_pitch_to_written_pitch
      tools/instrumenttools/transpose_from_written_pitch_to_sounding_pitch

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/instrumenttools/Accordion
      tools/instrumenttools/AltoFlute
      tools/instrumenttools/AltoSaxophone
      tools/instrumenttools/AltoTrombone
      tools/instrumenttools/AltoVoice
      tools/instrumenttools/BaritoneSaxophone
      tools/instrumenttools/BaritoneVoice
      tools/instrumenttools/BassClarinet
      tools/instrumenttools/BassFlute
      tools/instrumenttools/BassSaxophone
      tools/instrumenttools/BassTrombone
      tools/instrumenttools/BassVoice
      tools/instrumenttools/Bassoon
      tools/instrumenttools/Cello
      tools/instrumenttools/ClarinetInA
      tools/instrumenttools/ClarinetInBFlat
      tools/instrumenttools/ClarinetInEFlat
      tools/instrumenttools/Contrabass
      tools/instrumenttools/ContrabassClarinet
      tools/instrumenttools/ContrabassFlute
      tools/instrumenttools/ContrabassSaxophone
      tools/instrumenttools/Contrabassoon
      tools/instrumenttools/EnglishHorn
      tools/instrumenttools/Flute
      tools/instrumenttools/FrenchHorn
      tools/instrumenttools/Glockenspiel
      tools/instrumenttools/Guitar
      tools/instrumenttools/Harp
      tools/instrumenttools/Harpsichord
      tools/instrumenttools/Instrument
      tools/instrumenttools/InstrumentInventory
      tools/instrumenttools/InstrumentationSpecifier
      tools/instrumenttools/Marimba
      tools/instrumenttools/MezzoSopranoVoice
      tools/instrumenttools/Oboe
      tools/instrumenttools/Performer
      tools/instrumenttools/PerformerInventory
      tools/instrumenttools/Piano
      tools/instrumenttools/Piccolo
      tools/instrumenttools/SopraninoSaxophone
      tools/instrumenttools/SopranoSaxophone
      tools/instrumenttools/SopranoVoice
      tools/instrumenttools/TenorSaxophone
      tools/instrumenttools/TenorTrombone
      tools/instrumenttools/TenorVoice
      tools/instrumenttools/Trumpet
      tools/instrumenttools/Tuba
      tools/instrumenttools/UntunedPercussion
      tools/instrumenttools/Vibraphone
      tools/instrumenttools/Viola
      tools/instrumenttools/Violin
      tools/instrumenttools/WoodwindFingering
      tools/instrumenttools/Xylophone

   Functions
   ---------

   .. toctree::

      tools/instrumenttools/iterate_out_of_range_notes_and_chords
      tools/instrumenttools/notes_and_chords_are_in_range
      tools/instrumenttools/notes_and_chords_are_on_expected_clefs
      tools/instrumenttools/transpose_from_sounding_pitch_to_written_pitch
      tools/instrumenttools/transpose_from_written_pitch_to_sounding_pitch

:py:mod:`labeltools <abjad.tools.labeltools>`
=============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/labeltools/index

   .. toctree::
      :maxdepth: 1

      tools/labeltools/color_chord_note_heads_in_expr_by_pitch_class_color_map
      tools/labeltools/color_contents_of_container
      tools/labeltools/color_leaf
      tools/labeltools/color_leaves_in_expr
      tools/labeltools/color_measure
      tools/labeltools/color_measures_with_non_power_of_two_denominators_in_expr
      tools/labeltools/color_note_head_by_numbered_pitch_class_color_map
      tools/labeltools/label_leaves_in_expr_with_leaf_depth
      tools/labeltools/label_leaves_in_expr_with_leaf_duration
      tools/labeltools/label_leaves_in_expr_with_leaf_durations
      tools/labeltools/label_leaves_in_expr_with_leaf_indices
      tools/labeltools/label_leaves_in_expr_with_leaf_numbers
      tools/labeltools/label_leaves_in_expr_with_named_interval_classes
      tools/labeltools/label_leaves_in_expr_with_named_intervals
      tools/labeltools/label_leaves_in_expr_with_numbered_interval_classes
      tools/labeltools/label_leaves_in_expr_with_numbered_intervals
      tools/labeltools/label_leaves_in_expr_with_numbered_inversion_equivalent_interval_classes
      tools/labeltools/label_leaves_in_expr_with_pitch_class_numbers
      tools/labeltools/label_leaves_in_expr_with_pitch_numbers
      tools/labeltools/label_leaves_in_expr_with_tuplet_depth
      tools/labeltools/label_leaves_in_expr_with_written_leaf_duration
      tools/labeltools/label_logical_ties_in_expr_with_logical_tie_duration
      tools/labeltools/label_logical_ties_in_expr_with_logical_tie_durations
      tools/labeltools/label_logical_ties_in_expr_with_written_logical_tie_duration
      tools/labeltools/label_notes_in_expr_with_note_indices
      tools/labeltools/label_vertical_moments_in_expr_with_interval_class_vectors
      tools/labeltools/label_vertical_moments_in_expr_with_named_intervals
      tools/labeltools/label_vertical_moments_in_expr_with_numbered_interval_classes
      tools/labeltools/label_vertical_moments_in_expr_with_numbered_intervals
      tools/labeltools/label_vertical_moments_in_expr_with_numbered_pitch_classes
      tools/labeltools/label_vertical_moments_in_expr_with_pitch_numbers
      tools/labeltools/remove_markup_from_leaves_in_expr

.. only:: latex

   Functions
   ---------

   .. toctree::

      tools/labeltools/color_chord_note_heads_in_expr_by_pitch_class_color_map
      tools/labeltools/color_contents_of_container
      tools/labeltools/color_leaf
      tools/labeltools/color_leaves_in_expr
      tools/labeltools/color_measure
      tools/labeltools/color_measures_with_non_power_of_two_denominators_in_expr
      tools/labeltools/color_note_head_by_numbered_pitch_class_color_map
      tools/labeltools/label_leaves_in_expr_with_leaf_depth
      tools/labeltools/label_leaves_in_expr_with_leaf_duration
      tools/labeltools/label_leaves_in_expr_with_leaf_durations
      tools/labeltools/label_leaves_in_expr_with_leaf_indices
      tools/labeltools/label_leaves_in_expr_with_leaf_numbers
      tools/labeltools/label_leaves_in_expr_with_named_interval_classes
      tools/labeltools/label_leaves_in_expr_with_named_intervals
      tools/labeltools/label_leaves_in_expr_with_numbered_interval_classes
      tools/labeltools/label_leaves_in_expr_with_numbered_intervals
      tools/labeltools/label_leaves_in_expr_with_numbered_inversion_equivalent_interval_classes
      tools/labeltools/label_leaves_in_expr_with_pitch_class_numbers
      tools/labeltools/label_leaves_in_expr_with_pitch_numbers
      tools/labeltools/label_leaves_in_expr_with_tuplet_depth
      tools/labeltools/label_leaves_in_expr_with_written_leaf_duration
      tools/labeltools/label_logical_ties_in_expr_with_logical_tie_duration
      tools/labeltools/label_logical_ties_in_expr_with_logical_tie_durations
      tools/labeltools/label_logical_ties_in_expr_with_written_logical_tie_duration
      tools/labeltools/label_notes_in_expr_with_note_indices
      tools/labeltools/label_vertical_moments_in_expr_with_interval_class_vectors
      tools/labeltools/label_vertical_moments_in_expr_with_named_intervals
      tools/labeltools/label_vertical_moments_in_expr_with_numbered_interval_classes
      tools/labeltools/label_vertical_moments_in_expr_with_numbered_intervals
      tools/labeltools/label_vertical_moments_in_expr_with_numbered_pitch_classes
      tools/labeltools/label_vertical_moments_in_expr_with_pitch_numbers
      tools/labeltools/remove_markup_from_leaves_in_expr

:py:mod:`layouttools <abjad.tools.layouttools>`
===============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/layouttools/index

   .. toctree::
      :maxdepth: 1

      tools/layouttools/SpacingIndication

   .. toctree::
      :maxdepth: 1

      tools/layouttools/make_spacing_vector
      tools/layouttools/set_line_breaks_by_line_duration
      tools/layouttools/set_line_breaks_cyclically_by_line_duration_ge
      tools/layouttools/set_line_breaks_cyclically_by_line_duration_in_seconds_ge

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/layouttools/SpacingIndication

   Functions
   ---------

   .. toctree::

      tools/layouttools/make_spacing_vector
      tools/layouttools/set_line_breaks_by_line_duration
      tools/layouttools/set_line_breaks_cyclically_by_line_duration_ge
      tools/layouttools/set_line_breaks_cyclically_by_line_duration_in_seconds_ge

:py:mod:`lilypondfiletools <abjad.tools.lilypondfiletools>`
===========================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/lilypondfiletools/index

   .. toctree::
      :maxdepth: 1

      tools/lilypondfiletools/AttributedBlock
      tools/lilypondfiletools/NonattributedBlock

   .. toctree::
      :maxdepth: 1

      tools/lilypondfiletools/BookBlock
      tools/lilypondfiletools/BookpartBlock
      tools/lilypondfiletools/ContextBlock
      tools/lilypondfiletools/DateTimeToken
      tools/lilypondfiletools/HeaderBlock
      tools/lilypondfiletools/LayoutBlock
      tools/lilypondfiletools/LilyPondDimension
      tools/lilypondfiletools/LilyPondFile
      tools/lilypondfiletools/LilyPondLanguageToken
      tools/lilypondfiletools/LilyPondVersionToken
      tools/lilypondfiletools/MIDIBlock
      tools/lilypondfiletools/PaperBlock
      tools/lilypondfiletools/ScoreBlock

   .. toctree::
      :maxdepth: 1

      tools/lilypondfiletools/make_basic_lilypond_file
      tools/lilypondfiletools/make_floating_time_signature_lilypond_file
      tools/lilypondfiletools/make_time_signature_context_block

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/lilypondfiletools/AttributedBlock
      tools/lilypondfiletools/NonattributedBlock

   Concrete classes
   ----------------

   .. toctree::

      tools/lilypondfiletools/BookBlock
      tools/lilypondfiletools/BookpartBlock
      tools/lilypondfiletools/ContextBlock
      tools/lilypondfiletools/DateTimeToken
      tools/lilypondfiletools/HeaderBlock
      tools/lilypondfiletools/LayoutBlock
      tools/lilypondfiletools/LilyPondDimension
      tools/lilypondfiletools/LilyPondFile
      tools/lilypondfiletools/LilyPondLanguageToken
      tools/lilypondfiletools/LilyPondVersionToken
      tools/lilypondfiletools/MIDIBlock
      tools/lilypondfiletools/PaperBlock
      tools/lilypondfiletools/ScoreBlock

   Functions
   ---------

   .. toctree::

      tools/lilypondfiletools/make_basic_lilypond_file
      tools/lilypondfiletools/make_floating_time_signature_lilypond_file
      tools/lilypondfiletools/make_time_signature_context_block

:py:mod:`markuptools <abjad.tools.markuptools>`
===============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/markuptools/index

   .. toctree::
      :maxdepth: 1

      tools/markuptools/Markup
      tools/markuptools/MarkupCommand
      tools/markuptools/MarkupInventory
      tools/markuptools/MusicGlyph

   .. toctree::
      :maxdepth: 1

      tools/markuptools/combine_markup_commands
      tools/markuptools/make_big_centered_page_number_markup
      tools/markuptools/make_blank_line_markup
      tools/markuptools/make_centered_title_markup
      tools/markuptools/make_vertically_adjusted_composer_markup

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/markuptools/Markup
      tools/markuptools/MarkupCommand
      tools/markuptools/MarkupInventory
      tools/markuptools/MusicGlyph

   Functions
   ---------

   .. toctree::

      tools/markuptools/combine_markup_commands
      tools/markuptools/make_big_centered_page_number_markup
      tools/markuptools/make_blank_line_markup
      tools/markuptools/make_centered_title_markup
      tools/markuptools/make_vertically_adjusted_composer_markup

:py:mod:`mathtools <abjad.tools.mathtools>`
===========================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/mathtools/index

   .. toctree::
      :maxdepth: 1

      tools/mathtools/BoundedObject
      tools/mathtools/Infinity
      tools/mathtools/NegativeInfinity
      tools/mathtools/NonreducedFraction
      tools/mathtools/NonreducedRatio
      tools/mathtools/Ratio

   .. toctree::
      :maxdepth: 1

      tools/mathtools/are_relatively_prime
      tools/mathtools/arithmetic_mean
      tools/mathtools/binomial_coefficient
      tools/mathtools/cumulative_products
      tools/mathtools/cumulative_signed_weights
      tools/mathtools/cumulative_sums
      tools/mathtools/cumulative_sums_pairwise
      tools/mathtools/difference_series
      tools/mathtools/divide_number_by_ratio
      tools/mathtools/divisors
      tools/mathtools/factors
      tools/mathtools/fraction_to_proper_fraction
      tools/mathtools/get_shared_numeric_sign
      tools/mathtools/greatest_common_divisor
      tools/mathtools/greatest_multiple_less_equal
      tools/mathtools/greatest_power_of_two_less_equal
      tools/mathtools/integer_equivalent_number_to_integer
      tools/mathtools/integer_to_base_k_tuple
      tools/mathtools/integer_to_binary_string
      tools/mathtools/is_assignable_integer
      tools/mathtools/is_dotted_integer
      tools/mathtools/is_integer_equivalent_expr
      tools/mathtools/is_integer_equivalent_number
      tools/mathtools/is_negative_integer
      tools/mathtools/is_nonnegative_integer
      tools/mathtools/is_nonnegative_integer_equivalent_number
      tools/mathtools/is_nonnegative_integer_power_of_two
      tools/mathtools/is_positive_integer
      tools/mathtools/is_positive_integer_equivalent_number
      tools/mathtools/is_positive_integer_power_of_two
      tools/mathtools/least_common_multiple
      tools/mathtools/least_multiple_greater_equal
      tools/mathtools/least_power_of_two_greater_equal
      tools/mathtools/next_integer_partition
      tools/mathtools/partition_integer_by_ratio
      tools/mathtools/partition_integer_into_canonic_parts
      tools/mathtools/partition_integer_into_halves
      tools/mathtools/partition_integer_into_parts_less_than_double
      tools/mathtools/partition_integer_into_units
      tools/mathtools/remove_powers_of_two
      tools/mathtools/sign
      tools/mathtools/weight
      tools/mathtools/yield_all_compositions_of_integer
      tools/mathtools/yield_all_partitions_of_integer
      tools/mathtools/yield_nonreduced_fractions

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/mathtools/BoundedObject
      tools/mathtools/Infinity
      tools/mathtools/NegativeInfinity
      tools/mathtools/NonreducedFraction
      tools/mathtools/NonreducedRatio
      tools/mathtools/Ratio

   Functions
   ---------

   .. toctree::

      tools/mathtools/are_relatively_prime
      tools/mathtools/arithmetic_mean
      tools/mathtools/binomial_coefficient
      tools/mathtools/cumulative_products
      tools/mathtools/cumulative_signed_weights
      tools/mathtools/cumulative_sums
      tools/mathtools/cumulative_sums_pairwise
      tools/mathtools/difference_series
      tools/mathtools/divide_number_by_ratio
      tools/mathtools/divisors
      tools/mathtools/factors
      tools/mathtools/fraction_to_proper_fraction
      tools/mathtools/get_shared_numeric_sign
      tools/mathtools/greatest_common_divisor
      tools/mathtools/greatest_multiple_less_equal
      tools/mathtools/greatest_power_of_two_less_equal
      tools/mathtools/integer_equivalent_number_to_integer
      tools/mathtools/integer_to_base_k_tuple
      tools/mathtools/integer_to_binary_string
      tools/mathtools/is_assignable_integer
      tools/mathtools/is_dotted_integer
      tools/mathtools/is_integer_equivalent_expr
      tools/mathtools/is_integer_equivalent_number
      tools/mathtools/is_negative_integer
      tools/mathtools/is_nonnegative_integer
      tools/mathtools/is_nonnegative_integer_equivalent_number
      tools/mathtools/is_nonnegative_integer_power_of_two
      tools/mathtools/is_positive_integer
      tools/mathtools/is_positive_integer_equivalent_number
      tools/mathtools/is_positive_integer_power_of_two
      tools/mathtools/least_common_multiple
      tools/mathtools/least_multiple_greater_equal
      tools/mathtools/least_power_of_two_greater_equal
      tools/mathtools/next_integer_partition
      tools/mathtools/partition_integer_by_ratio
      tools/mathtools/partition_integer_into_canonic_parts
      tools/mathtools/partition_integer_into_halves
      tools/mathtools/partition_integer_into_parts_less_than_double
      tools/mathtools/partition_integer_into_units
      tools/mathtools/remove_powers_of_two
      tools/mathtools/sign
      tools/mathtools/weight
      tools/mathtools/yield_all_compositions_of_integer
      tools/mathtools/yield_all_partitions_of_integer
      tools/mathtools/yield_nonreduced_fractions

:py:mod:`metertools <abjad.tools.metertools>`
=============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/metertools/index

   .. toctree::
      :maxdepth: 1

      tools/metertools/Meter
      tools/metertools/MetricAccentKernel

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/metertools/Meter
      tools/metertools/MetricAccentKernel

:py:mod:`pitcharraytools <abjad.tools.pitcharraytools>`
=======================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/pitcharraytools/index

   .. toctree::
      :maxdepth: 1

      tools/pitcharraytools/PitchArray
      tools/pitcharraytools/PitchArrayCell
      tools/pitcharraytools/PitchArrayColumn
      tools/pitcharraytools/PitchArrayInventory
      tools/pitcharraytools/PitchArrayRow

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/pitcharraytools/PitchArray
      tools/pitcharraytools/PitchArrayCell
      tools/pitcharraytools/PitchArrayColumn
      tools/pitcharraytools/PitchArrayInventory
      tools/pitcharraytools/PitchArrayRow

:py:mod:`pitchtools <abjad.tools.pitchtools>`
=============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/pitchtools/index

   .. toctree::
      :maxdepth: 1

      tools/pitchtools/Interval
      tools/pitchtools/IntervalClass
      tools/pitchtools/Pitch
      tools/pitchtools/PitchClass
      tools/pitchtools/Segment
      tools/pitchtools/Set
      tools/pitchtools/Vector

   .. toctree::
      :maxdepth: 1

      tools/pitchtools/Accidental
      tools/pitchtools/IntervalClassSegment
      tools/pitchtools/IntervalClassSet
      tools/pitchtools/IntervalClassVector
      tools/pitchtools/IntervalSegment
      tools/pitchtools/IntervalSet
      tools/pitchtools/IntervalVector
      tools/pitchtools/NamedInterval
      tools/pitchtools/NamedIntervalClass
      tools/pitchtools/NamedInversionEquivalentIntervalClass
      tools/pitchtools/NamedPitch
      tools/pitchtools/NamedPitchClass
      tools/pitchtools/NumberedInterval
      tools/pitchtools/NumberedIntervalClass
      tools/pitchtools/NumberedInversionEquivalentIntervalClass
      tools/pitchtools/NumberedPitch
      tools/pitchtools/NumberedPitchClass
      tools/pitchtools/NumberedPitchClassColorMap
      tools/pitchtools/Octave
      tools/pitchtools/OctaveTranspositionMapping
      tools/pitchtools/OctaveTranspositionMappingComponent
      tools/pitchtools/OctaveTranspositionMappingInventory
      tools/pitchtools/PitchClassSegment
      tools/pitchtools/PitchClassSet
      tools/pitchtools/PitchClassVector
      tools/pitchtools/PitchRange
      tools/pitchtools/PitchRangeInventory
      tools/pitchtools/PitchSegment
      tools/pitchtools/PitchSet
      tools/pitchtools/PitchVector
      tools/pitchtools/TwelveToneRow

   .. toctree::
      :maxdepth: 1

      tools/pitchtools/apply_accidental_to_named_pitch
      tools/pitchtools/clef_and_staff_position_number_to_named_pitch
      tools/pitchtools/contains_subsegment
      tools/pitchtools/get_named_pitch_from_pitch_carrier
      tools/pitchtools/get_numbered_pitch_class_from_pitch_carrier
      tools/pitchtools/insert_and_transpose_nested_subruns_in_pitch_class_number_list
      tools/pitchtools/instantiate_pitch_and_interval_test_collection
      tools/pitchtools/inventory_aggregate_subsets
      tools/pitchtools/iterate_named_pitch_pairs_in_expr
      tools/pitchtools/list_named_pitches_in_expr
      tools/pitchtools/list_numbered_interval_numbers_pairwise
      tools/pitchtools/list_numbered_inversion_equivalent_interval_classes_pairwise
      tools/pitchtools/list_octave_transpositions_of_pitch_carrier_within_pitch_range
      tools/pitchtools/list_ordered_named_pitch_pairs_from_expr_1_to_expr_2
      tools/pitchtools/list_pitch_numbers_in_expr
      tools/pitchtools/list_unordered_named_pitch_pairs_in_expr
      tools/pitchtools/make_n_middle_c_centered_pitches
      tools/pitchtools/named_pitch_and_clef_to_staff_position_number
      tools/pitchtools/numbered_inversion_equivalent_interval_class_dictionary
      tools/pitchtools/permute_named_pitch_carrier_list_by_twelve_tone_row
      tools/pitchtools/register_pitch_class_numbers_by_pitch_number_aggregate
      tools/pitchtools/set_written_pitch_of_pitched_components_in_expr
      tools/pitchtools/sort_named_pitch_carriers_in_expr
      tools/pitchtools/spell_numbered_interval_number
      tools/pitchtools/spell_pitch_number
      tools/pitchtools/suggest_clef_for_named_pitches
      tools/pitchtools/transpose_named_pitch_by_numbered_interval_and_respell
      tools/pitchtools/transpose_pitch_carrier_by_interval
      tools/pitchtools/transpose_pitch_class_number_to_pitch_number_neighbor
      tools/pitchtools/transpose_pitch_expr_into_pitch_range
      tools/pitchtools/transpose_pitch_number_by_octave_transposition_mapping

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/pitchtools/Interval
      tools/pitchtools/IntervalClass
      tools/pitchtools/Pitch
      tools/pitchtools/PitchClass
      tools/pitchtools/Segment
      tools/pitchtools/Set
      tools/pitchtools/Vector

   Concrete classes
   ----------------

   .. toctree::

      tools/pitchtools/Accidental
      tools/pitchtools/IntervalClassSegment
      tools/pitchtools/IntervalClassSet
      tools/pitchtools/IntervalClassVector
      tools/pitchtools/IntervalSegment
      tools/pitchtools/IntervalSet
      tools/pitchtools/IntervalVector
      tools/pitchtools/NamedInterval
      tools/pitchtools/NamedIntervalClass
      tools/pitchtools/NamedInversionEquivalentIntervalClass
      tools/pitchtools/NamedPitch
      tools/pitchtools/NamedPitchClass
      tools/pitchtools/NumberedInterval
      tools/pitchtools/NumberedIntervalClass
      tools/pitchtools/NumberedInversionEquivalentIntervalClass
      tools/pitchtools/NumberedPitch
      tools/pitchtools/NumberedPitchClass
      tools/pitchtools/NumberedPitchClassColorMap
      tools/pitchtools/Octave
      tools/pitchtools/OctaveTranspositionMapping
      tools/pitchtools/OctaveTranspositionMappingComponent
      tools/pitchtools/OctaveTranspositionMappingInventory
      tools/pitchtools/PitchClassSegment
      tools/pitchtools/PitchClassSet
      tools/pitchtools/PitchClassVector
      tools/pitchtools/PitchRange
      tools/pitchtools/PitchRangeInventory
      tools/pitchtools/PitchSegment
      tools/pitchtools/PitchSet
      tools/pitchtools/PitchVector
      tools/pitchtools/TwelveToneRow

   Functions
   ---------

   .. toctree::

      tools/pitchtools/apply_accidental_to_named_pitch
      tools/pitchtools/clef_and_staff_position_number_to_named_pitch
      tools/pitchtools/contains_subsegment
      tools/pitchtools/get_named_pitch_from_pitch_carrier
      tools/pitchtools/get_numbered_pitch_class_from_pitch_carrier
      tools/pitchtools/insert_and_transpose_nested_subruns_in_pitch_class_number_list
      tools/pitchtools/instantiate_pitch_and_interval_test_collection
      tools/pitchtools/inventory_aggregate_subsets
      tools/pitchtools/iterate_named_pitch_pairs_in_expr
      tools/pitchtools/list_named_pitches_in_expr
      tools/pitchtools/list_numbered_interval_numbers_pairwise
      tools/pitchtools/list_numbered_inversion_equivalent_interval_classes_pairwise
      tools/pitchtools/list_octave_transpositions_of_pitch_carrier_within_pitch_range
      tools/pitchtools/list_ordered_named_pitch_pairs_from_expr_1_to_expr_2
      tools/pitchtools/list_pitch_numbers_in_expr
      tools/pitchtools/list_unordered_named_pitch_pairs_in_expr
      tools/pitchtools/make_n_middle_c_centered_pitches
      tools/pitchtools/named_pitch_and_clef_to_staff_position_number
      tools/pitchtools/numbered_inversion_equivalent_interval_class_dictionary
      tools/pitchtools/permute_named_pitch_carrier_list_by_twelve_tone_row
      tools/pitchtools/register_pitch_class_numbers_by_pitch_number_aggregate
      tools/pitchtools/set_written_pitch_of_pitched_components_in_expr
      tools/pitchtools/sort_named_pitch_carriers_in_expr
      tools/pitchtools/spell_numbered_interval_number
      tools/pitchtools/spell_pitch_number
      tools/pitchtools/suggest_clef_for_named_pitches
      tools/pitchtools/transpose_named_pitch_by_numbered_interval_and_respell
      tools/pitchtools/transpose_pitch_carrier_by_interval
      tools/pitchtools/transpose_pitch_class_number_to_pitch_number_neighbor
      tools/pitchtools/transpose_pitch_expr_into_pitch_range
      tools/pitchtools/transpose_pitch_number_by_octave_transposition_mapping

:py:mod:`quantizationtools <abjad.tools.quantizationtools>`
===========================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/quantizationtools/index

   .. toctree::
      :maxdepth: 1

      tools/quantizationtools/AttackPointOptimizer
      tools/quantizationtools/GraceHandler
      tools/quantizationtools/Heuristic
      tools/quantizationtools/JobHandler
      tools/quantizationtools/QEvent
      tools/quantizationtools/QSchema
      tools/quantizationtools/QSchemaItem
      tools/quantizationtools/QTarget
      tools/quantizationtools/SearchTree

   .. toctree::
      :maxdepth: 1

      tools/quantizationtools/BeatwiseQSchema
      tools/quantizationtools/BeatwiseQSchemaItem
      tools/quantizationtools/BeatwiseQTarget
      tools/quantizationtools/CollapsingGraceHandler
      tools/quantizationtools/ConcatenatingGraceHandler
      tools/quantizationtools/DiscardingGraceHandler
      tools/quantizationtools/DistanceHeuristic
      tools/quantizationtools/MeasurewiseAttackPointOptimizer
      tools/quantizationtools/MeasurewiseQSchema
      tools/quantizationtools/MeasurewiseQSchemaItem
      tools/quantizationtools/MeasurewiseQTarget
      tools/quantizationtools/NaiveAttackPointOptimizer
      tools/quantizationtools/NullAttackPointOptimizer
      tools/quantizationtools/ParallelJobHandler
      tools/quantizationtools/ParallelJobHandlerWorker
      tools/quantizationtools/PitchedQEvent
      tools/quantizationtools/QEventProxy
      tools/quantizationtools/QEventSequence
      tools/quantizationtools/QGrid
      tools/quantizationtools/QGridContainer
      tools/quantizationtools/QGridLeaf
      tools/quantizationtools/QTargetBeat
      tools/quantizationtools/QTargetMeasure
      tools/quantizationtools/QuantizationJob
      tools/quantizationtools/Quantizer
      tools/quantizationtools/SerialJobHandler
      tools/quantizationtools/SilentQEvent
      tools/quantizationtools/TerminalQEvent
      tools/quantizationtools/UnweightedSearchTree
      tools/quantizationtools/WeightedSearchTree

   .. toctree::
      :maxdepth: 1

      tools/quantizationtools/make_test_time_segments

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/quantizationtools/AttackPointOptimizer
      tools/quantizationtools/GraceHandler
      tools/quantizationtools/Heuristic
      tools/quantizationtools/JobHandler
      tools/quantizationtools/QEvent
      tools/quantizationtools/QSchema
      tools/quantizationtools/QSchemaItem
      tools/quantizationtools/QTarget
      tools/quantizationtools/SearchTree

   Concrete classes
   ----------------

   .. toctree::

      tools/quantizationtools/BeatwiseQSchema
      tools/quantizationtools/BeatwiseQSchemaItem
      tools/quantizationtools/BeatwiseQTarget
      tools/quantizationtools/CollapsingGraceHandler
      tools/quantizationtools/ConcatenatingGraceHandler
      tools/quantizationtools/DiscardingGraceHandler
      tools/quantizationtools/DistanceHeuristic
      tools/quantizationtools/MeasurewiseAttackPointOptimizer
      tools/quantizationtools/MeasurewiseQSchema
      tools/quantizationtools/MeasurewiseQSchemaItem
      tools/quantizationtools/MeasurewiseQTarget
      tools/quantizationtools/NaiveAttackPointOptimizer
      tools/quantizationtools/NullAttackPointOptimizer
      tools/quantizationtools/ParallelJobHandler
      tools/quantizationtools/ParallelJobHandlerWorker
      tools/quantizationtools/PitchedQEvent
      tools/quantizationtools/QEventProxy
      tools/quantizationtools/QEventSequence
      tools/quantizationtools/QGrid
      tools/quantizationtools/QGridContainer
      tools/quantizationtools/QGridLeaf
      tools/quantizationtools/QTargetBeat
      tools/quantizationtools/QTargetMeasure
      tools/quantizationtools/QuantizationJob
      tools/quantizationtools/Quantizer
      tools/quantizationtools/SerialJobHandler
      tools/quantizationtools/SilentQEvent
      tools/quantizationtools/TerminalQEvent
      tools/quantizationtools/UnweightedSearchTree
      tools/quantizationtools/WeightedSearchTree

   Functions
   ---------

   .. toctree::

      tools/quantizationtools/make_test_time_segments

:py:mod:`rhythmmakertools <abjad.tools.rhythmmakertools>`
=========================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/rhythmmakertools/index

   .. toctree::
      :maxdepth: 1

      tools/rhythmmakertools/BurnishedRhythmMaker
      tools/rhythmmakertools/DivisionIncisedRhythmMaker
      tools/rhythmmakertools/IncisedRhythmMaker
      tools/rhythmmakertools/OutputIncisedRhythmMaker
      tools/rhythmmakertools/RhythmMaker

   .. toctree::
      :maxdepth: 1

      tools/rhythmmakertools/DivisionBurnishedTaleaRhythmMaker
      tools/rhythmmakertools/DivisionIncisedNoteRhythmMaker
      tools/rhythmmakertools/DivisionIncisedRestRhythmMaker
      tools/rhythmmakertools/EqualDivisionRhythmMaker
      tools/rhythmmakertools/EvenRunRhythmMaker
      tools/rhythmmakertools/NoteRhythmMaker
      tools/rhythmmakertools/OutputBurnishedTaleaRhythmMaker
      tools/rhythmmakertools/OutputIncisedNoteRhythmMaker
      tools/rhythmmakertools/OutputIncisedRestRhythmMaker
      tools/rhythmmakertools/RestRhythmMaker
      tools/rhythmmakertools/SkipRhythmMaker
      tools/rhythmmakertools/TaleaRhythmMaker
      tools/rhythmmakertools/TupletMonadRhythmMaker

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/rhythmmakertools/BurnishedRhythmMaker
      tools/rhythmmakertools/DivisionIncisedRhythmMaker
      tools/rhythmmakertools/IncisedRhythmMaker
      tools/rhythmmakertools/OutputIncisedRhythmMaker
      tools/rhythmmakertools/RhythmMaker

   Concrete classes
   ----------------

   .. toctree::

      tools/rhythmmakertools/DivisionBurnishedTaleaRhythmMaker
      tools/rhythmmakertools/DivisionIncisedNoteRhythmMaker
      tools/rhythmmakertools/DivisionIncisedRestRhythmMaker
      tools/rhythmmakertools/EqualDivisionRhythmMaker
      tools/rhythmmakertools/EvenRunRhythmMaker
      tools/rhythmmakertools/NoteRhythmMaker
      tools/rhythmmakertools/OutputBurnishedTaleaRhythmMaker
      tools/rhythmmakertools/OutputIncisedNoteRhythmMaker
      tools/rhythmmakertools/OutputIncisedRestRhythmMaker
      tools/rhythmmakertools/RestRhythmMaker
      tools/rhythmmakertools/SkipRhythmMaker
      tools/rhythmmakertools/TaleaRhythmMaker
      tools/rhythmmakertools/TupletMonadRhythmMaker

:py:mod:`rhythmtreetools <abjad.tools.rhythmtreetools>`
=======================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/rhythmtreetools/index

   .. toctree::
      :maxdepth: 1

      tools/rhythmtreetools/RhythmTreeNode

   .. toctree::
      :maxdepth: 1

      tools/rhythmtreetools/RhythmTreeContainer
      tools/rhythmtreetools/RhythmTreeLeaf
      tools/rhythmtreetools/RhythmTreeParser

   .. toctree::
      :maxdepth: 1

      tools/rhythmtreetools/parse_rtm_syntax

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/rhythmtreetools/RhythmTreeNode

   Concrete classes
   ----------------

   .. toctree::

      tools/rhythmtreetools/RhythmTreeContainer
      tools/rhythmtreetools/RhythmTreeLeaf
      tools/rhythmtreetools/RhythmTreeParser

   Functions
   ---------

   .. toctree::

      tools/rhythmtreetools/parse_rtm_syntax

:py:mod:`schemetools <abjad.tools.schemetools>`
===============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/schemetools/index

   .. toctree::
      :maxdepth: 1

      tools/schemetools/Scheme
      tools/schemetools/SchemeAssociativeList
      tools/schemetools/SchemeColor
      tools/schemetools/SchemeMoment
      tools/schemetools/SchemePair
      tools/schemetools/SchemeVector
      tools/schemetools/SchemeVectorConstant

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/schemetools/Scheme
      tools/schemetools/SchemeAssociativeList
      tools/schemetools/SchemeColor
      tools/schemetools/SchemeMoment
      tools/schemetools/SchemePair
      tools/schemetools/SchemeVector
      tools/schemetools/SchemeVectorConstant

:py:mod:`scoretools <abjad.tools.scoretools>`
=============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/scoretools/index

   .. toctree::
      :maxdepth: 1

      tools/scoretools/Component
      tools/scoretools/Leaf

   .. toctree::
      :maxdepth: 1

      tools/scoretools/Chord
      tools/scoretools/Cluster
      tools/scoretools/Container
      tools/scoretools/Context
      tools/scoretools/FixedDurationContainer
      tools/scoretools/FixedDurationTuplet
      tools/scoretools/GraceContainer
      tools/scoretools/GrandStaff
      tools/scoretools/Measure
      tools/scoretools/MultimeasureRest
      tools/scoretools/Note
      tools/scoretools/NoteHead
      tools/scoretools/NoteHeadInventory
      tools/scoretools/PianoStaff
      tools/scoretools/Rest
      tools/scoretools/RhythmicStaff
      tools/scoretools/Score
      tools/scoretools/Skip
      tools/scoretools/Staff
      tools/scoretools/StaffGroup
      tools/scoretools/Tuplet
      tools/scoretools/Voice

   .. toctree::
      :maxdepth: 1

      tools/scoretools/append_spacer_skip_to_underfull_measure
      tools/scoretools/append_spacer_skips_to_underfull_measures_in_expr
      tools/scoretools/apply_full_measure_tuplets_to_contents_of_measures_in_expr
      tools/scoretools/extend_measures_in_expr_and_apply_full_measure_tuplets
      tools/scoretools/fill_measures_in_expr_with_full_measure_spacer_skips
      tools/scoretools/fill_measures_in_expr_with_minimal_number_of_notes
      tools/scoretools/fill_measures_in_expr_with_repeated_notes
      tools/scoretools/fill_measures_in_expr_with_time_signature_denominator_notes
      tools/scoretools/get_measure_that_starts_with_container
      tools/scoretools/get_measure_that_stops_with_container
      tools/scoretools/get_next_measure_from_component
      tools/scoretools/get_one_indexed_measure_number_in_expr
      tools/scoretools/get_previous_measure_from_component
      tools/scoretools/make_empty_piano_score
      tools/scoretools/make_leaves
      tools/scoretools/make_leaves_from_talea
      tools/scoretools/make_multimeasure_rests
      tools/scoretools/make_multiplied_quarter_notes
      tools/scoretools/make_notes
      tools/scoretools/make_notes_with_multiplied_durations
      tools/scoretools/make_percussion_note
      tools/scoretools/make_piano_score_from_leaves
      tools/scoretools/make_piano_sketch_score_from_leaves
      tools/scoretools/make_repeated_notes
      tools/scoretools/make_repeated_notes_from_time_signature
      tools/scoretools/make_repeated_notes_from_time_signatures
      tools/scoretools/make_repeated_notes_with_shorter_notes_at_end
      tools/scoretools/make_repeated_rests_from_time_signatures
      tools/scoretools/make_repeated_skips_from_time_signatures
      tools/scoretools/make_rests
      tools/scoretools/make_rhythmic_sketch_staff
      tools/scoretools/make_skips_with_multiplied_durations
      tools/scoretools/make_spacer_skip_measures
      tools/scoretools/make_tied_leaf
      tools/scoretools/move_full_measure_tuplet_prolation_to_measure_time_signature
      tools/scoretools/move_measure_prolation_to_full_measure_tuplet
      tools/scoretools/replace_contents_of_measures_in_expr
      tools/scoretools/scale_measure_denominator_and_adjust_measure_contents
      tools/scoretools/set_always_format_time_signature_of_measures_in_expr
      tools/scoretools/set_measure_denominator_and_adjust_numerator

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/scoretools/Component
      tools/scoretools/Leaf

   Concrete classes
   ----------------

   .. toctree::

      tools/scoretools/Chord
      tools/scoretools/Cluster
      tools/scoretools/Container
      tools/scoretools/Context
      tools/scoretools/FixedDurationContainer
      tools/scoretools/FixedDurationTuplet
      tools/scoretools/GraceContainer
      tools/scoretools/GrandStaff
      tools/scoretools/Measure
      tools/scoretools/MultimeasureRest
      tools/scoretools/Note
      tools/scoretools/NoteHead
      tools/scoretools/NoteHeadInventory
      tools/scoretools/PianoStaff
      tools/scoretools/Rest
      tools/scoretools/RhythmicStaff
      tools/scoretools/Score
      tools/scoretools/Skip
      tools/scoretools/Staff
      tools/scoretools/StaffGroup
      tools/scoretools/Tuplet
      tools/scoretools/Voice

   Functions
   ---------

   .. toctree::

      tools/scoretools/append_spacer_skip_to_underfull_measure
      tools/scoretools/append_spacer_skips_to_underfull_measures_in_expr
      tools/scoretools/apply_full_measure_tuplets_to_contents_of_measures_in_expr
      tools/scoretools/extend_measures_in_expr_and_apply_full_measure_tuplets
      tools/scoretools/fill_measures_in_expr_with_full_measure_spacer_skips
      tools/scoretools/fill_measures_in_expr_with_minimal_number_of_notes
      tools/scoretools/fill_measures_in_expr_with_repeated_notes
      tools/scoretools/fill_measures_in_expr_with_time_signature_denominator_notes
      tools/scoretools/get_measure_that_starts_with_container
      tools/scoretools/get_measure_that_stops_with_container
      tools/scoretools/get_next_measure_from_component
      tools/scoretools/get_one_indexed_measure_number_in_expr
      tools/scoretools/get_previous_measure_from_component
      tools/scoretools/make_empty_piano_score
      tools/scoretools/make_leaves
      tools/scoretools/make_leaves_from_talea
      tools/scoretools/make_multimeasure_rests
      tools/scoretools/make_multiplied_quarter_notes
      tools/scoretools/make_notes
      tools/scoretools/make_notes_with_multiplied_durations
      tools/scoretools/make_percussion_note
      tools/scoretools/make_piano_score_from_leaves
      tools/scoretools/make_piano_sketch_score_from_leaves
      tools/scoretools/make_repeated_notes
      tools/scoretools/make_repeated_notes_from_time_signature
      tools/scoretools/make_repeated_notes_from_time_signatures
      tools/scoretools/make_repeated_notes_with_shorter_notes_at_end
      tools/scoretools/make_repeated_rests_from_time_signatures
      tools/scoretools/make_repeated_skips_from_time_signatures
      tools/scoretools/make_rests
      tools/scoretools/make_rhythmic_sketch_staff
      tools/scoretools/make_skips_with_multiplied_durations
      tools/scoretools/make_spacer_skip_measures
      tools/scoretools/make_tied_leaf
      tools/scoretools/move_full_measure_tuplet_prolation_to_measure_time_signature
      tools/scoretools/move_measure_prolation_to_full_measure_tuplet
      tools/scoretools/replace_contents_of_measures_in_expr
      tools/scoretools/scale_measure_denominator_and_adjust_measure_contents
      tools/scoretools/set_always_format_time_signature_of_measures_in_expr
      tools/scoretools/set_measure_denominator_and_adjust_numerator

:py:mod:`selectiontools <abjad.tools.selectiontools>`
=====================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/selectiontools/index

   .. toctree::
      :maxdepth: 1

      tools/selectiontools/ContiguousSelection
      tools/selectiontools/Descendants
      tools/selectiontools/Lineage
      tools/selectiontools/LogicalTie
      tools/selectiontools/Parentage
      tools/selectiontools/Selection
      tools/selectiontools/SelectionInventory
      tools/selectiontools/SimultaneousSelection
      tools/selectiontools/SliceSelection
      tools/selectiontools/VerticalMoment

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/selectiontools/ContiguousSelection
      tools/selectiontools/Descendants
      tools/selectiontools/Lineage
      tools/selectiontools/LogicalTie
      tools/selectiontools/Parentage
      tools/selectiontools/Selection
      tools/selectiontools/SelectionInventory
      tools/selectiontools/SimultaneousSelection
      tools/selectiontools/SliceSelection
      tools/selectiontools/VerticalMoment

:py:mod:`sequencetools <abjad.tools.sequencetools>`
===================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/sequencetools/index

   .. toctree::
      :maxdepth: 1

      tools/sequencetools/all_are_assignable_integers
      tools/sequencetools/all_are_equal
      tools/sequencetools/all_are_integer_equivalent_exprs
      tools/sequencetools/all_are_integer_equivalent_numbers
      tools/sequencetools/all_are_nonnegative_integer_equivalent_numbers
      tools/sequencetools/all_are_nonnegative_integer_powers_of_two
      tools/sequencetools/all_are_nonnegative_integers
      tools/sequencetools/all_are_numbers
      tools/sequencetools/all_are_pairs
      tools/sequencetools/all_are_pairs_of_types
      tools/sequencetools/all_are_positive_integer_equivalent_numbers
      tools/sequencetools/all_are_positive_integers
      tools/sequencetools/all_are_unequal
      tools/sequencetools/count_length_two_runs_in_sequence
      tools/sequencetools/divide_sequence_elements_by_greatest_common_divisor
      tools/sequencetools/flatten_sequence
      tools/sequencetools/flatten_sequence_at_indices
      tools/sequencetools/get_indices_of_sequence_elements_equal_to_true
      tools/sequencetools/get_sequence_degree_of_rotational_symmetry
      tools/sequencetools/get_sequence_element_at_cyclic_index
      tools/sequencetools/get_sequence_elements_at_indices
      tools/sequencetools/get_sequence_elements_frequency_distribution
      tools/sequencetools/get_sequence_period_of_rotation
      tools/sequencetools/increase_sequence_elements_at_indices_by_addenda
      tools/sequencetools/increase_sequence_elements_cyclically_by_addenda
      tools/sequencetools/interlace_sequences
      tools/sequencetools/is_fraction_equivalent_pair
      tools/sequencetools/is_integer_equivalent_n_tuple
      tools/sequencetools/is_integer_equivalent_pair
      tools/sequencetools/is_integer_equivalent_singleton
      tools/sequencetools/is_integer_n_tuple
      tools/sequencetools/is_integer_pair
      tools/sequencetools/is_integer_singleton
      tools/sequencetools/is_monotonically_decreasing_sequence
      tools/sequencetools/is_monotonically_increasing_sequence
      tools/sequencetools/is_n_tuple
      tools/sequencetools/is_null_tuple
      tools/sequencetools/is_pair
      tools/sequencetools/is_permutation
      tools/sequencetools/is_repetition_free_sequence
      tools/sequencetools/is_restricted_growth_function
      tools/sequencetools/is_singleton
      tools/sequencetools/is_strictly_decreasing_sequence
      tools/sequencetools/is_strictly_increasing_sequence
      tools/sequencetools/iterate_sequence_cyclically
      tools/sequencetools/iterate_sequence_cyclically_from_start_to_stop
      tools/sequencetools/iterate_sequence_forward_and_backward_nonoverlapping
      tools/sequencetools/iterate_sequence_forward_and_backward_overlapping
      tools/sequencetools/iterate_sequence_nwise_cyclic
      tools/sequencetools/iterate_sequence_nwise_strict
      tools/sequencetools/iterate_sequence_nwise_wrapped
      tools/sequencetools/iterate_sequence_pairwise_cyclic
      tools/sequencetools/iterate_sequence_pairwise_strict
      tools/sequencetools/iterate_sequence_pairwise_wrapped
      tools/sequencetools/join_subsequences
      tools/sequencetools/join_subsequences_by_sign_of_subsequence_elements
      tools/sequencetools/map_sequence_elements_to_canonic_tuples
      tools/sequencetools/map_sequence_elements_to_numbered_sublists
      tools/sequencetools/merge_duration_sequences
      tools/sequencetools/negate_absolute_value_of_sequence_elements_at_indices
      tools/sequencetools/negate_absolute_value_of_sequence_elements_cyclically
      tools/sequencetools/negate_sequence_elements_at_indices
      tools/sequencetools/negate_sequence_elements_cyclically
      tools/sequencetools/overwrite_sequence_elements_at_indices
      tools/sequencetools/pair_duration_sequence_elements_with_input_pair_values
      tools/sequencetools/partition_sequence_by_backgrounded_weights
      tools/sequencetools/partition_sequence_by_counts
      tools/sequencetools/partition_sequence_by_ratio_of_lengths
      tools/sequencetools/partition_sequence_by_ratio_of_weights
      tools/sequencetools/partition_sequence_by_restricted_growth_function
      tools/sequencetools/partition_sequence_by_sign_of_elements
      tools/sequencetools/partition_sequence_by_value_of_elements
      tools/sequencetools/partition_sequence_by_weights_at_least
      tools/sequencetools/partition_sequence_by_weights_at_most
      tools/sequencetools/partition_sequence_by_weights_exactly
      tools/sequencetools/partition_sequence_extended_to_counts
      tools/sequencetools/permute_sequence
      tools/sequencetools/remap_sequence_by_range_pairs
      tools/sequencetools/remove_sequence_elements_at_indices
      tools/sequencetools/remove_sequence_elements_at_indices_cyclically
      tools/sequencetools/remove_subsequence_of_weight_at_index
      tools/sequencetools/repeat_runs_in_sequence_to_count
      tools/sequencetools/repeat_sequence_elements_at_indices
      tools/sequencetools/repeat_sequence_elements_at_indices_cyclically
      tools/sequencetools/repeat_sequence_elements_n_times_each
      tools/sequencetools/repeat_sequence_n_times
      tools/sequencetools/repeat_sequence_to_length
      tools/sequencetools/repeat_sequence_to_weight_at_least
      tools/sequencetools/repeat_sequence_to_weight_at_most
      tools/sequencetools/repeat_sequence_to_weight_exactly
      tools/sequencetools/replace_sequence_elements_cyclically_with_new_material
      tools/sequencetools/retain_sequence_elements_at_indices
      tools/sequencetools/retain_sequence_elements_at_indices_cyclically
      tools/sequencetools/reverse_sequence
      tools/sequencetools/reverse_sequence_elements
      tools/sequencetools/rotate_sequence
      tools/sequencetools/splice_new_elements_between_sequence_elements
      tools/sequencetools/split_sequence_by_weights
      tools/sequencetools/split_sequence_extended_to_weights
      tools/sequencetools/sum_consecutive_sequence_elements_by_sign
      tools/sequencetools/sum_sequence_elements_at_indices
      tools/sequencetools/truncate_runs_in_sequence
      tools/sequencetools/truncate_sequence_to_sum
      tools/sequencetools/truncate_sequence_to_weight
      tools/sequencetools/yield_all_combinations_of_sequence_elements
      tools/sequencetools/yield_all_k_ary_sequences_of_length
      tools/sequencetools/yield_all_pairs_between_sequences
      tools/sequencetools/yield_all_partitions_of_sequence
      tools/sequencetools/yield_all_permutations_of_sequence
      tools/sequencetools/yield_all_permutations_of_sequence_in_orbit
      tools/sequencetools/yield_all_restricted_growth_functions_of_length
      tools/sequencetools/yield_all_rotations_of_sequence
      tools/sequencetools/yield_all_set_partitions_of_sequence
      tools/sequencetools/yield_all_subsequences_of_sequence
      tools/sequencetools/yield_all_unordered_pairs_of_sequence
      tools/sequencetools/yield_outer_product_of_sequences
      tools/sequencetools/zip_sequences_cyclically
      tools/sequencetools/zip_sequences_without_truncation

.. only:: latex

   Functions
   ---------

   .. toctree::

      tools/sequencetools/all_are_assignable_integers
      tools/sequencetools/all_are_equal
      tools/sequencetools/all_are_integer_equivalent_exprs
      tools/sequencetools/all_are_integer_equivalent_numbers
      tools/sequencetools/all_are_nonnegative_integer_equivalent_numbers
      tools/sequencetools/all_are_nonnegative_integer_powers_of_two
      tools/sequencetools/all_are_nonnegative_integers
      tools/sequencetools/all_are_numbers
      tools/sequencetools/all_are_pairs
      tools/sequencetools/all_are_pairs_of_types
      tools/sequencetools/all_are_positive_integer_equivalent_numbers
      tools/sequencetools/all_are_positive_integers
      tools/sequencetools/all_are_unequal
      tools/sequencetools/count_length_two_runs_in_sequence
      tools/sequencetools/divide_sequence_elements_by_greatest_common_divisor
      tools/sequencetools/flatten_sequence
      tools/sequencetools/flatten_sequence_at_indices
      tools/sequencetools/get_indices_of_sequence_elements_equal_to_true
      tools/sequencetools/get_sequence_degree_of_rotational_symmetry
      tools/sequencetools/get_sequence_element_at_cyclic_index
      tools/sequencetools/get_sequence_elements_at_indices
      tools/sequencetools/get_sequence_elements_frequency_distribution
      tools/sequencetools/get_sequence_period_of_rotation
      tools/sequencetools/increase_sequence_elements_at_indices_by_addenda
      tools/sequencetools/increase_sequence_elements_cyclically_by_addenda
      tools/sequencetools/interlace_sequences
      tools/sequencetools/is_fraction_equivalent_pair
      tools/sequencetools/is_integer_equivalent_n_tuple
      tools/sequencetools/is_integer_equivalent_pair
      tools/sequencetools/is_integer_equivalent_singleton
      tools/sequencetools/is_integer_n_tuple
      tools/sequencetools/is_integer_pair
      tools/sequencetools/is_integer_singleton
      tools/sequencetools/is_monotonically_decreasing_sequence
      tools/sequencetools/is_monotonically_increasing_sequence
      tools/sequencetools/is_n_tuple
      tools/sequencetools/is_null_tuple
      tools/sequencetools/is_pair
      tools/sequencetools/is_permutation
      tools/sequencetools/is_repetition_free_sequence
      tools/sequencetools/is_restricted_growth_function
      tools/sequencetools/is_singleton
      tools/sequencetools/is_strictly_decreasing_sequence
      tools/sequencetools/is_strictly_increasing_sequence
      tools/sequencetools/iterate_sequence_cyclically
      tools/sequencetools/iterate_sequence_cyclically_from_start_to_stop
      tools/sequencetools/iterate_sequence_forward_and_backward_nonoverlapping
      tools/sequencetools/iterate_sequence_forward_and_backward_overlapping
      tools/sequencetools/iterate_sequence_nwise_cyclic
      tools/sequencetools/iterate_sequence_nwise_strict
      tools/sequencetools/iterate_sequence_nwise_wrapped
      tools/sequencetools/iterate_sequence_pairwise_cyclic
      tools/sequencetools/iterate_sequence_pairwise_strict
      tools/sequencetools/iterate_sequence_pairwise_wrapped
      tools/sequencetools/join_subsequences
      tools/sequencetools/join_subsequences_by_sign_of_subsequence_elements
      tools/sequencetools/map_sequence_elements_to_canonic_tuples
      tools/sequencetools/map_sequence_elements_to_numbered_sublists
      tools/sequencetools/merge_duration_sequences
      tools/sequencetools/negate_absolute_value_of_sequence_elements_at_indices
      tools/sequencetools/negate_absolute_value_of_sequence_elements_cyclically
      tools/sequencetools/negate_sequence_elements_at_indices
      tools/sequencetools/negate_sequence_elements_cyclically
      tools/sequencetools/overwrite_sequence_elements_at_indices
      tools/sequencetools/pair_duration_sequence_elements_with_input_pair_values
      tools/sequencetools/partition_sequence_by_backgrounded_weights
      tools/sequencetools/partition_sequence_by_counts
      tools/sequencetools/partition_sequence_by_ratio_of_lengths
      tools/sequencetools/partition_sequence_by_ratio_of_weights
      tools/sequencetools/partition_sequence_by_restricted_growth_function
      tools/sequencetools/partition_sequence_by_sign_of_elements
      tools/sequencetools/partition_sequence_by_value_of_elements
      tools/sequencetools/partition_sequence_by_weights_at_least
      tools/sequencetools/partition_sequence_by_weights_at_most
      tools/sequencetools/partition_sequence_by_weights_exactly
      tools/sequencetools/partition_sequence_extended_to_counts
      tools/sequencetools/permute_sequence
      tools/sequencetools/remap_sequence_by_range_pairs
      tools/sequencetools/remove_sequence_elements_at_indices
      tools/sequencetools/remove_sequence_elements_at_indices_cyclically
      tools/sequencetools/remove_subsequence_of_weight_at_index
      tools/sequencetools/repeat_runs_in_sequence_to_count
      tools/sequencetools/repeat_sequence_elements_at_indices
      tools/sequencetools/repeat_sequence_elements_at_indices_cyclically
      tools/sequencetools/repeat_sequence_elements_n_times_each
      tools/sequencetools/repeat_sequence_n_times
      tools/sequencetools/repeat_sequence_to_length
      tools/sequencetools/repeat_sequence_to_weight_at_least
      tools/sequencetools/repeat_sequence_to_weight_at_most
      tools/sequencetools/repeat_sequence_to_weight_exactly
      tools/sequencetools/replace_sequence_elements_cyclically_with_new_material
      tools/sequencetools/retain_sequence_elements_at_indices
      tools/sequencetools/retain_sequence_elements_at_indices_cyclically
      tools/sequencetools/reverse_sequence
      tools/sequencetools/reverse_sequence_elements
      tools/sequencetools/rotate_sequence
      tools/sequencetools/splice_new_elements_between_sequence_elements
      tools/sequencetools/split_sequence_by_weights
      tools/sequencetools/split_sequence_extended_to_weights
      tools/sequencetools/sum_consecutive_sequence_elements_by_sign
      tools/sequencetools/sum_sequence_elements_at_indices
      tools/sequencetools/truncate_runs_in_sequence
      tools/sequencetools/truncate_sequence_to_sum
      tools/sequencetools/truncate_sequence_to_weight
      tools/sequencetools/yield_all_combinations_of_sequence_elements
      tools/sequencetools/yield_all_k_ary_sequences_of_length
      tools/sequencetools/yield_all_pairs_between_sequences
      tools/sequencetools/yield_all_partitions_of_sequence
      tools/sequencetools/yield_all_permutations_of_sequence
      tools/sequencetools/yield_all_permutations_of_sequence_in_orbit
      tools/sequencetools/yield_all_restricted_growth_functions_of_length
      tools/sequencetools/yield_all_rotations_of_sequence
      tools/sequencetools/yield_all_set_partitions_of_sequence
      tools/sequencetools/yield_all_subsequences_of_sequence
      tools/sequencetools/yield_all_unordered_pairs_of_sequence
      tools/sequencetools/yield_outer_product_of_sequences
      tools/sequencetools/zip_sequences_cyclically
      tools/sequencetools/zip_sequences_without_truncation

:py:mod:`sievetools <abjad.tools.sievetools>`
=============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/sievetools/index

   .. toctree::
      :maxdepth: 1

      tools/sievetools/BaseResidueClass
      tools/sievetools/ResidueClass
      tools/sievetools/Sieve

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/sievetools/BaseResidueClass
      tools/sievetools/ResidueClass
      tools/sievetools/Sieve

:py:mod:`spannertools <abjad.tools.spannertools>`
=================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/spannertools/index

   .. toctree::
      :maxdepth: 1

      tools/spannertools/Beam
      tools/spannertools/ComplexBeam
      tools/spannertools/Crescendo
      tools/spannertools/Decrescendo
      tools/spannertools/DuratedComplexBeam
      tools/spannertools/DynamicTextSpanner
      tools/spannertools/Glissando
      tools/spannertools/Hairpin
      tools/spannertools/HiddenStaffSpanner
      tools/spannertools/HorizontalBracketSpanner
      tools/spannertools/MeasuredComplexBeam
      tools/spannertools/MultipartBeam
      tools/spannertools/OctavationSpanner
      tools/spannertools/PhrasingSlur
      tools/spannertools/PianoPedalSpanner
      tools/spannertools/Slur
      tools/spannertools/Spanner
      tools/spannertools/StaffLinesSpanner
      tools/spannertools/TextScriptSpanner
      tools/spannertools/TextSpanner
      tools/spannertools/Tie
      tools/spannertools/TrillSpanner

   .. toctree::
      :maxdepth: 1

      tools/spannertools/make_colored_text_spanner_with_nibs
      tools/spannertools/make_dynamic_spanner_below_with_nib_at_right
      tools/spannertools/make_solid_text_spanner_with_nib

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/spannertools/Beam
      tools/spannertools/ComplexBeam
      tools/spannertools/Crescendo
      tools/spannertools/Decrescendo
      tools/spannertools/DuratedComplexBeam
      tools/spannertools/DynamicTextSpanner
      tools/spannertools/Glissando
      tools/spannertools/Hairpin
      tools/spannertools/HiddenStaffSpanner
      tools/spannertools/HorizontalBracketSpanner
      tools/spannertools/MeasuredComplexBeam
      tools/spannertools/MultipartBeam
      tools/spannertools/OctavationSpanner
      tools/spannertools/PhrasingSlur
      tools/spannertools/PianoPedalSpanner
      tools/spannertools/Slur
      tools/spannertools/Spanner
      tools/spannertools/StaffLinesSpanner
      tools/spannertools/TextScriptSpanner
      tools/spannertools/TextSpanner
      tools/spannertools/Tie
      tools/spannertools/TrillSpanner

   Functions
   ---------

   .. toctree::

      tools/spannertools/make_colored_text_spanner_with_nibs
      tools/spannertools/make_dynamic_spanner_below_with_nib_at_right
      tools/spannertools/make_solid_text_spanner_with_nib

:py:mod:`stringtools <abjad.tools.stringtools>`
===============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/stringtools/index

   .. toctree::
      :maxdepth: 1

      tools/stringtools/add_terminal_newlines
      tools/stringtools/arg_to_bidirectional_direction_string
      tools/stringtools/arg_to_bidirectional_lilypond_symbol
      tools/stringtools/arg_to_tridirectional_direction_string
      tools/stringtools/arg_to_tridirectional_lilypond_symbol
      tools/stringtools/arg_to_tridirectional_ordinal_constant
      tools/stringtools/capitalize_string_start
      tools/stringtools/format_input_lines_as_doc_string
      tools/stringtools/format_input_lines_as_regression_test
      tools/stringtools/is_dash_case_file_name
      tools/stringtools/is_dash_case_string
      tools/stringtools/is_lower_camel_case_string
      tools/stringtools/is_snake_case_file_name
      tools/stringtools/is_snake_case_file_name_with_extension
      tools/stringtools/is_snake_case_package_name
      tools/stringtools/is_snake_case_string
      tools/stringtools/is_space_delimited_lowercase_string
      tools/stringtools/is_upper_camel_case_string
      tools/stringtools/pluralize_string
      tools/stringtools/snake_case_to_lower_camel_case
      tools/stringtools/snake_case_to_upper_camel_case
      tools/stringtools/space_delimited_lowercase_to_upper_camel_case
      tools/stringtools/string_to_accent_free_snake_case
      tools/stringtools/string_to_space_delimited_lowercase
      tools/stringtools/strip_diacritics_from_binary_string
      tools/stringtools/upper_camel_case_to_snake_case
      tools/stringtools/upper_camel_case_to_space_delimited_lowercase

.. only:: latex

   Functions
   ---------

   .. toctree::

      tools/stringtools/add_terminal_newlines
      tools/stringtools/arg_to_bidirectional_direction_string
      tools/stringtools/arg_to_bidirectional_lilypond_symbol
      tools/stringtools/arg_to_tridirectional_direction_string
      tools/stringtools/arg_to_tridirectional_lilypond_symbol
      tools/stringtools/arg_to_tridirectional_ordinal_constant
      tools/stringtools/capitalize_string_start
      tools/stringtools/format_input_lines_as_doc_string
      tools/stringtools/format_input_lines_as_regression_test
      tools/stringtools/is_dash_case_file_name
      tools/stringtools/is_dash_case_string
      tools/stringtools/is_lower_camel_case_string
      tools/stringtools/is_snake_case_file_name
      tools/stringtools/is_snake_case_file_name_with_extension
      tools/stringtools/is_snake_case_package_name
      tools/stringtools/is_snake_case_string
      tools/stringtools/is_space_delimited_lowercase_string
      tools/stringtools/is_upper_camel_case_string
      tools/stringtools/pluralize_string
      tools/stringtools/snake_case_to_lower_camel_case
      tools/stringtools/snake_case_to_upper_camel_case
      tools/stringtools/space_delimited_lowercase_to_upper_camel_case
      tools/stringtools/string_to_accent_free_snake_case
      tools/stringtools/string_to_space_delimited_lowercase
      tools/stringtools/strip_diacritics_from_binary_string
      tools/stringtools/upper_camel_case_to_snake_case
      tools/stringtools/upper_camel_case_to_space_delimited_lowercase

:py:mod:`templatetools <abjad.tools.templatetools>`
===================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/templatetools/index

   .. toctree::
      :maxdepth: 1

      tools/templatetools/GroupedRhythmicStavesScoreTemplate
      tools/templatetools/GroupedStavesScoreTemplate
      tools/templatetools/StringOrchestraScoreTemplate
      tools/templatetools/StringQuartetScoreTemplate
      tools/templatetools/TwoStaffPianoScoreTemplate

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/templatetools/GroupedRhythmicStavesScoreTemplate
      tools/templatetools/GroupedStavesScoreTemplate
      tools/templatetools/StringOrchestraScoreTemplate
      tools/templatetools/StringQuartetScoreTemplate
      tools/templatetools/TwoStaffPianoScoreTemplate

:py:mod:`timespantools <abjad.tools.timespantools>`
===================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/timespantools/index

   .. toctree::
      :maxdepth: 1

      tools/timespantools/TimeRelation

   .. toctree::
      :maxdepth: 1

      tools/timespantools/CompoundInequality
      tools/timespantools/OffsetTimespanTimeRelation
      tools/timespantools/SimpleInequality
      tools/timespantools/Timespan
      tools/timespantools/TimespanInventory
      tools/timespantools/TimespanTimespanTimeRelation

   .. toctree::
      :maxdepth: 1

      tools/timespantools/offset_happens_after_timespan_starts
      tools/timespantools/offset_happens_after_timespan_stops
      tools/timespantools/offset_happens_before_timespan_starts
      tools/timespantools/offset_happens_before_timespan_stops
      tools/timespantools/offset_happens_during_timespan
      tools/timespantools/offset_happens_when_timespan_starts
      tools/timespantools/offset_happens_when_timespan_stops
      tools/timespantools/timespan_2_contains_timespan_1_improperly
      tools/timespantools/timespan_2_curtails_timespan_1
      tools/timespantools/timespan_2_delays_timespan_1
      tools/timespantools/timespan_2_happens_during_timespan_1
      tools/timespantools/timespan_2_intersects_timespan_1
      tools/timespantools/timespan_2_is_congruent_to_timespan_1
      tools/timespantools/timespan_2_overlaps_all_of_timespan_1
      tools/timespantools/timespan_2_overlaps_only_start_of_timespan_1
      tools/timespantools/timespan_2_overlaps_only_stop_of_timespan_1
      tools/timespantools/timespan_2_overlaps_start_of_timespan_1
      tools/timespantools/timespan_2_overlaps_stop_of_timespan_1
      tools/timespantools/timespan_2_starts_after_timespan_1_starts
      tools/timespantools/timespan_2_starts_after_timespan_1_stops
      tools/timespantools/timespan_2_starts_before_timespan_1_starts
      tools/timespantools/timespan_2_starts_before_timespan_1_stops
      tools/timespantools/timespan_2_starts_during_timespan_1
      tools/timespantools/timespan_2_starts_when_timespan_1_starts
      tools/timespantools/timespan_2_starts_when_timespan_1_stops
      tools/timespantools/timespan_2_stops_after_timespan_1_starts
      tools/timespantools/timespan_2_stops_after_timespan_1_stops
      tools/timespantools/timespan_2_stops_before_timespan_1_starts
      tools/timespantools/timespan_2_stops_before_timespan_1_stops
      tools/timespantools/timespan_2_stops_during_timespan_1
      tools/timespantools/timespan_2_stops_when_timespan_1_starts
      tools/timespantools/timespan_2_stops_when_timespan_1_stops
      tools/timespantools/timespan_2_trisects_timespan_1

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/timespantools/TimeRelation

   Concrete classes
   ----------------

   .. toctree::

      tools/timespantools/CompoundInequality
      tools/timespantools/OffsetTimespanTimeRelation
      tools/timespantools/SimpleInequality
      tools/timespantools/Timespan
      tools/timespantools/TimespanInventory
      tools/timespantools/TimespanTimespanTimeRelation

   Functions
   ---------

   .. toctree::

      tools/timespantools/offset_happens_after_timespan_starts
      tools/timespantools/offset_happens_after_timespan_stops
      tools/timespantools/offset_happens_before_timespan_starts
      tools/timespantools/offset_happens_before_timespan_stops
      tools/timespantools/offset_happens_during_timespan
      tools/timespantools/offset_happens_when_timespan_starts
      tools/timespantools/offset_happens_when_timespan_stops
      tools/timespantools/timespan_2_contains_timespan_1_improperly
      tools/timespantools/timespan_2_curtails_timespan_1
      tools/timespantools/timespan_2_delays_timespan_1
      tools/timespantools/timespan_2_happens_during_timespan_1
      tools/timespantools/timespan_2_intersects_timespan_1
      tools/timespantools/timespan_2_is_congruent_to_timespan_1
      tools/timespantools/timespan_2_overlaps_all_of_timespan_1
      tools/timespantools/timespan_2_overlaps_only_start_of_timespan_1
      tools/timespantools/timespan_2_overlaps_only_stop_of_timespan_1
      tools/timespantools/timespan_2_overlaps_start_of_timespan_1
      tools/timespantools/timespan_2_overlaps_stop_of_timespan_1
      tools/timespantools/timespan_2_starts_after_timespan_1_starts
      tools/timespantools/timespan_2_starts_after_timespan_1_stops
      tools/timespantools/timespan_2_starts_before_timespan_1_starts
      tools/timespantools/timespan_2_starts_before_timespan_1_stops
      tools/timespantools/timespan_2_starts_during_timespan_1
      tools/timespantools/timespan_2_starts_when_timespan_1_starts
      tools/timespantools/timespan_2_starts_when_timespan_1_stops
      tools/timespantools/timespan_2_stops_after_timespan_1_starts
      tools/timespantools/timespan_2_stops_after_timespan_1_stops
      tools/timespantools/timespan_2_stops_before_timespan_1_starts
      tools/timespantools/timespan_2_stops_before_timespan_1_stops
      tools/timespantools/timespan_2_stops_during_timespan_1
      tools/timespantools/timespan_2_stops_when_timespan_1_starts
      tools/timespantools/timespan_2_stops_when_timespan_1_stops
      tools/timespantools/timespan_2_trisects_timespan_1

:py:mod:`tonalanalysistools <abjad.tools.tonalanalysistools>`
=============================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/tonalanalysistools/index

   .. toctree::
      :maxdepth: 1

      tools/tonalanalysistools/ChordExtent
      tools/tonalanalysistools/ChordInversion
      tools/tonalanalysistools/ChordOmission
      tools/tonalanalysistools/ChordQuality
      tools/tonalanalysistools/ChordSuspension
      tools/tonalanalysistools/Mode
      tools/tonalanalysistools/RomanNumeral
      tools/tonalanalysistools/RootedChordClass
      tools/tonalanalysistools/RootlessChordClass
      tools/tonalanalysistools/Scale
      tools/tonalanalysistools/ScaleDegree
      tools/tonalanalysistools/TonalAnalysisAgent

   .. toctree::
      :maxdepth: 1

      tools/tonalanalysistools/select

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/tonalanalysistools/ChordExtent
      tools/tonalanalysistools/ChordInversion
      tools/tonalanalysistools/ChordOmission
      tools/tonalanalysistools/ChordQuality
      tools/tonalanalysistools/ChordSuspension
      tools/tonalanalysistools/Mode
      tools/tonalanalysistools/RomanNumeral
      tools/tonalanalysistools/RootedChordClass
      tools/tonalanalysistools/RootlessChordClass
      tools/tonalanalysistools/Scale
      tools/tonalanalysistools/ScaleDegree
      tools/tonalanalysistools/TonalAnalysisAgent

   Functions
   ---------

   .. toctree::

      tools/tonalanalysistools/select

:py:mod:`topleveltools <abjad.tools.topleveltools>`
===================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/topleveltools/index

   .. toctree::
      :maxdepth: 1

      tools/topleveltools/attach
      tools/topleveltools/contextualize
      tools/topleveltools/detach
      tools/topleveltools/graph
      tools/topleveltools/iterate
      tools/topleveltools/mutate
      tools/topleveltools/new
      tools/topleveltools/override
      tools/topleveltools/parse
      tools/topleveltools/persist
      tools/topleveltools/play
      tools/topleveltools/select
      tools/topleveltools/show

.. only:: latex

   Functions
   ---------

   .. toctree::

      tools/topleveltools/attach
      tools/topleveltools/contextualize
      tools/topleveltools/detach
      tools/topleveltools/graph
      tools/topleveltools/iterate
      tools/topleveltools/mutate
      tools/topleveltools/new
      tools/topleveltools/override
      tools/topleveltools/parse
      tools/topleveltools/persist
      tools/topleveltools/play
      tools/topleveltools/select
      tools/topleveltools/show

**************************
Demos and example packages
**************************

:py:mod:`desordre <abjad.demos.desordre>`
=========================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      demos/desordre/index

   .. toctree::
      :maxdepth: 1

      demos/desordre/make_desordre_cell
      demos/desordre/make_desordre_lilypond_file
      demos/desordre/make_desordre_measure
      demos/desordre/make_desordre_pitches
      demos/desordre/make_desordre_score
      demos/desordre/make_desordre_staff

.. only:: latex

   Functions
   ---------

   .. toctree::

      demos/desordre/make_desordre_cell
      demos/desordre/make_desordre_lilypond_file
      demos/desordre/make_desordre_measure
      demos/desordre/make_desordre_pitches
      demos/desordre/make_desordre_score
      demos/desordre/make_desordre_staff

:py:mod:`ferneyhough <abjad.demos.ferneyhough>`
===============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      demos/ferneyhough/index

   .. toctree::
      :maxdepth: 1

      demos/ferneyhough/configure_lilypond_file
      demos/ferneyhough/configure_score
      demos/ferneyhough/make_lilypond_file
      demos/ferneyhough/make_nested_tuplet
      demos/ferneyhough/make_row_of_nested_tuplets
      demos/ferneyhough/make_rows_of_nested_tuplets
      demos/ferneyhough/make_score

.. only:: latex

   Functions
   ---------

   .. toctree::

      demos/ferneyhough/configure_lilypond_file
      demos/ferneyhough/configure_score
      demos/ferneyhough/make_lilypond_file
      demos/ferneyhough/make_nested_tuplet
      demos/ferneyhough/make_row_of_nested_tuplets
      demos/ferneyhough/make_rows_of_nested_tuplets
      demos/ferneyhough/make_score

:py:mod:`mozart <abjad.demos.mozart>`
=====================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      demos/mozart/index

   .. toctree::
      :maxdepth: 1

      demos/mozart/choose_mozart_measures
      demos/mozart/make_mozart_lilypond_file
      demos/mozart/make_mozart_measure
      demos/mozart/make_mozart_measure_corpus
      demos/mozart/make_mozart_score

.. only:: latex

   Functions
   ---------

   .. toctree::

      demos/mozart/choose_mozart_measures
      demos/mozart/make_mozart_lilypond_file
      demos/mozart/make_mozart_measure
      demos/mozart/make_mozart_measure_corpus
      demos/mozart/make_mozart_score

:py:mod:`part <abjad.demos.part>`
=================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      demos/part/index

   .. toctree::
      :maxdepth: 1

      demos/part/PartCantusScoreTemplate

   .. toctree::
      :maxdepth: 1

      demos/part/add_bell_music_to_score
      demos/part/add_string_music_to_score
      demos/part/apply_bowing_marks
      demos/part/apply_dynamics
      demos/part/apply_expressive_marks
      demos/part/apply_final_bar_lines
      demos/part/apply_page_breaks
      demos/part/apply_rehearsal_marks
      demos/part/configure_lilypond_file
      demos/part/configure_score
      demos/part/create_pitch_contour_reservoir
      demos/part/durate_pitch_contour_reservoir
      demos/part/edit_bass_voice
      demos/part/edit_cello_voice
      demos/part/edit_first_violin_voice
      demos/part/edit_second_violin_voice
      demos/part/edit_viola_voice
      demos/part/make_part_lilypond_file
      demos/part/shadow_pitch_contour_reservoir

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      demos/part/PartCantusScoreTemplate

   Functions
   ---------

   .. toctree::

      demos/part/add_bell_music_to_score
      demos/part/add_string_music_to_score
      demos/part/apply_bowing_marks
      demos/part/apply_dynamics
      demos/part/apply_expressive_marks
      demos/part/apply_final_bar_lines
      demos/part/apply_page_breaks
      demos/part/apply_rehearsal_marks
      demos/part/configure_lilypond_file
      demos/part/configure_score
      demos/part/create_pitch_contour_reservoir
      demos/part/durate_pitch_contour_reservoir
      demos/part/edit_bass_voice
      demos/part/edit_cello_voice
      demos/part/edit_first_violin_voice
      demos/part/edit_second_violin_voice
      demos/part/edit_viola_voice
      demos/part/make_part_lilypond_file
      demos/part/shadow_pitch_contour_reservoir

***********************
Abjad internal packages
***********************

:py:mod:`abctools <abjad.tools.abctools>`
=========================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/abctools/index

   .. toctree::
      :maxdepth: 1

      tools/abctools/ContextManager
      tools/abctools/Parser

   .. toctree::
      :maxdepth: 1

      tools/abctools/AbjadObject

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/abctools/ContextManager
      tools/abctools/Parser

   Concrete classes
   ----------------

   .. toctree::

      tools/abctools/AbjadObject

:py:mod:`abjadbooktools <abjad.tools.abjadbooktools>`
=====================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/abjadbooktools/index

   .. toctree::
      :maxdepth: 1

      tools/abjadbooktools/OutputFormat

   .. toctree::
      :maxdepth: 1

      tools/abjadbooktools/AbjadBookProcessor
      tools/abjadbooktools/AbjadBookScript
      tools/abjadbooktools/CodeBlock
      tools/abjadbooktools/HTMLOutputFormat
      tools/abjadbooktools/LaTeXOutputFormat
      tools/abjadbooktools/ReSTOutputFormat

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/abjadbooktools/OutputFormat

   Concrete classes
   ----------------

   .. toctree::

      tools/abjadbooktools/AbjadBookProcessor
      tools/abjadbooktools/AbjadBookScript
      tools/abjadbooktools/CodeBlock
      tools/abjadbooktools/HTMLOutputFormat
      tools/abjadbooktools/LaTeXOutputFormat
      tools/abjadbooktools/ReSTOutputFormat

:py:mod:`developerscripttools <abjad.tools.developerscripttools>`
=================================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/developerscripttools/index

   .. toctree::
      :maxdepth: 1

      tools/developerscripttools/DeveloperScript
      tools/developerscripttools/DirectoryScript

   .. toctree::
      :maxdepth: 1

      tools/developerscripttools/AbjDevScript
      tools/developerscripttools/AbjGrepScript
      tools/developerscripttools/BuildApiScript
      tools/developerscripttools/CleanScript
      tools/developerscripttools/CountLinewidthsScript
      tools/developerscripttools/CountToolsScript
      tools/developerscripttools/MakeNewClassTemplateScript
      tools/developerscripttools/MakeNewFunctionTemplateScript
      tools/developerscripttools/PyTestScript
      tools/developerscripttools/RenameModulesScript
      tools/developerscripttools/ReplaceInFilesScript
      tools/developerscripttools/RunDoctestsScript
      tools/developerscripttools/TestAndRebuildScript

   .. toctree::
      :maxdepth: 1

      tools/developerscripttools/get_developer_script_classes
      tools/developerscripttools/run_abjadbook
      tools/developerscripttools/run_ajv

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/developerscripttools/DeveloperScript
      tools/developerscripttools/DirectoryScript

   Concrete classes
   ----------------

   .. toctree::

      tools/developerscripttools/AbjDevScript
      tools/developerscripttools/AbjGrepScript
      tools/developerscripttools/BuildApiScript
      tools/developerscripttools/CleanScript
      tools/developerscripttools/CountLinewidthsScript
      tools/developerscripttools/CountToolsScript
      tools/developerscripttools/MakeNewClassTemplateScript
      tools/developerscripttools/MakeNewFunctionTemplateScript
      tools/developerscripttools/PyTestScript
      tools/developerscripttools/RenameModulesScript
      tools/developerscripttools/ReplaceInFilesScript
      tools/developerscripttools/RunDoctestsScript
      tools/developerscripttools/TestAndRebuildScript

   Functions
   ---------

   .. toctree::

      tools/developerscripttools/get_developer_script_classes
      tools/developerscripttools/run_abjadbook
      tools/developerscripttools/run_ajv

:py:mod:`documentationtools <abjad.tools.documentationtools>`
=============================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/documentationtools/index

   .. toctree::
      :maxdepth: 1

      tools/documentationtools/GraphvizObject
      tools/documentationtools/ReSTDirective

   .. toctree::
      :maxdepth: 1

      tools/documentationtools/AbjadAPIGenerator
      tools/documentationtools/ClassCrawler
      tools/documentationtools/ClassDocumenter
      tools/documentationtools/Documenter
      tools/documentationtools/FunctionCrawler
      tools/documentationtools/FunctionDocumenter
      tools/documentationtools/GraphvizEdge
      tools/documentationtools/GraphvizGraph
      tools/documentationtools/GraphvizNode
      tools/documentationtools/GraphvizSubgraph
      tools/documentationtools/InheritanceGraph
      tools/documentationtools/ModuleCrawler
      tools/documentationtools/Pipe
      tools/documentationtools/ReSTAutodocDirective
      tools/documentationtools/ReSTAutosummaryDirective
      tools/documentationtools/ReSTAutosummaryItem
      tools/documentationtools/ReSTDocument
      tools/documentationtools/ReSTHeading
      tools/documentationtools/ReSTHorizontalRule
      tools/documentationtools/ReSTInheritanceDiagram
      tools/documentationtools/ReSTLineageDirective
      tools/documentationtools/ReSTOnlyDirective
      tools/documentationtools/ReSTParagraph
      tools/documentationtools/ReSTTOCDirective
      tools/documentationtools/ReSTTOCItem
      tools/documentationtools/ToolsPackageDocumenter

   .. toctree::
      :maxdepth: 1

      tools/documentationtools/compare_images
      tools/documentationtools/list_all_abjad_classes
      tools/documentationtools/list_all_abjad_functions
      tools/documentationtools/make_ligeti_example_lilypond_file
      tools/documentationtools/make_reference_manual_graphviz_graph
      tools/documentationtools/make_reference_manual_lilypond_file
      tools/documentationtools/make_text_alignment_example_lilypond_file

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/documentationtools/GraphvizObject
      tools/documentationtools/ReSTDirective

   Concrete classes
   ----------------

   .. toctree::

      tools/documentationtools/AbjadAPIGenerator
      tools/documentationtools/ClassCrawler
      tools/documentationtools/ClassDocumenter
      tools/documentationtools/Documenter
      tools/documentationtools/FunctionCrawler
      tools/documentationtools/FunctionDocumenter
      tools/documentationtools/GraphvizEdge
      tools/documentationtools/GraphvizGraph
      tools/documentationtools/GraphvizNode
      tools/documentationtools/GraphvizSubgraph
      tools/documentationtools/InheritanceGraph
      tools/documentationtools/ModuleCrawler
      tools/documentationtools/Pipe
      tools/documentationtools/ReSTAutodocDirective
      tools/documentationtools/ReSTAutosummaryDirective
      tools/documentationtools/ReSTAutosummaryItem
      tools/documentationtools/ReSTDocument
      tools/documentationtools/ReSTHeading
      tools/documentationtools/ReSTHorizontalRule
      tools/documentationtools/ReSTInheritanceDiagram
      tools/documentationtools/ReSTLineageDirective
      tools/documentationtools/ReSTOnlyDirective
      tools/documentationtools/ReSTParagraph
      tools/documentationtools/ReSTTOCDirective
      tools/documentationtools/ReSTTOCItem
      tools/documentationtools/ToolsPackageDocumenter

   Functions
   ---------

   .. toctree::

      tools/documentationtools/compare_images
      tools/documentationtools/list_all_abjad_classes
      tools/documentationtools/list_all_abjad_functions
      tools/documentationtools/make_ligeti_example_lilypond_file
      tools/documentationtools/make_reference_manual_graphviz_graph
      tools/documentationtools/make_reference_manual_lilypond_file
      tools/documentationtools/make_text_alignment_example_lilypond_file

:py:mod:`exceptiontools <abjad.tools.exceptiontools>`
=====================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/exceptiontools/index

   .. toctree::
      :maxdepth: 1

      tools/exceptiontools/AssignabilityError
      tools/exceptiontools/ExtraSpannerError
      tools/exceptiontools/ImpreciseTempoError
      tools/exceptiontools/LilyPondParserError
      tools/exceptiontools/MissingMeasureError
      tools/exceptiontools/MissingSpannerError
      tools/exceptiontools/MissingTempoError
      tools/exceptiontools/OverfullContainerError
      tools/exceptiontools/PartitionError
      tools/exceptiontools/SchemeParserFinishedError
      tools/exceptiontools/UnboundedTimeIntervalError
      tools/exceptiontools/UnderfullContainerError

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/exceptiontools/AssignabilityError
      tools/exceptiontools/ExtraSpannerError
      tools/exceptiontools/ImpreciseTempoError
      tools/exceptiontools/LilyPondParserError
      tools/exceptiontools/MissingMeasureError
      tools/exceptiontools/MissingSpannerError
      tools/exceptiontools/MissingTempoError
      tools/exceptiontools/OverfullContainerError
      tools/exceptiontools/PartitionError
      tools/exceptiontools/SchemeParserFinishedError
      tools/exceptiontools/UnboundedTimeIntervalError
      tools/exceptiontools/UnderfullContainerError

:py:mod:`lilypondnametools <abjad.tools.lilypondnametools>`
===========================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/lilypondnametools/index

   .. toctree::
      :maxdepth: 1

      tools/lilypondnametools/LilyPondGrobNameManager
      tools/lilypondnametools/LilyPondNameManager
      tools/lilypondnametools/LilyPondSettingNameManager

.. only:: latex

   Concrete classes
   ----------------

   .. toctree::

      tools/lilypondnametools/LilyPondGrobNameManager
      tools/lilypondnametools/LilyPondNameManager
      tools/lilypondnametools/LilyPondSettingNameManager

:py:mod:`lilypondparsertools <abjad.tools.lilypondparsertools>`
===============================================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/lilypondparsertools/index

   .. toctree::
      :maxdepth: 1

      tools/lilypondparsertools/Music
      tools/lilypondparsertools/SimultaneousMusic

   .. toctree::
      :maxdepth: 1

      tools/lilypondparsertools/ContextSpeccedMusic
      tools/lilypondparsertools/GuileProxy
      tools/lilypondparsertools/LilyPondDuration
      tools/lilypondparsertools/LilyPondEvent
      tools/lilypondparsertools/LilyPondFraction
      tools/lilypondparsertools/LilyPondGrammarGenerator
      tools/lilypondparsertools/LilyPondLexicalDefinition
      tools/lilypondparsertools/LilyPondParser
      tools/lilypondparsertools/LilyPondSyntacticalDefinition
      tools/lilypondparsertools/ReducedLyParser
      tools/lilypondparsertools/SchemeParser
      tools/lilypondparsertools/SequentialMusic
      tools/lilypondparsertools/SyntaxNode

   .. toctree::
      :maxdepth: 1

      tools/lilypondparsertools/parse_reduced_ly_syntax

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/lilypondparsertools/Music
      tools/lilypondparsertools/SimultaneousMusic

   Concrete classes
   ----------------

   .. toctree::

      tools/lilypondparsertools/ContextSpeccedMusic
      tools/lilypondparsertools/GuileProxy
      tools/lilypondparsertools/LilyPondDuration
      tools/lilypondparsertools/LilyPondEvent
      tools/lilypondparsertools/LilyPondFraction
      tools/lilypondparsertools/LilyPondGrammarGenerator
      tools/lilypondparsertools/LilyPondLexicalDefinition
      tools/lilypondparsertools/LilyPondParser
      tools/lilypondparsertools/LilyPondSyntacticalDefinition
      tools/lilypondparsertools/ReducedLyParser
      tools/lilypondparsertools/SchemeParser
      tools/lilypondparsertools/SequentialMusic
      tools/lilypondparsertools/SyntaxNode

   Functions
   ---------

   .. toctree::

      tools/lilypondparsertools/parse_reduced_ly_syntax

:py:mod:`systemtools <abjad.tools.systemtools>`
===============================================

.. only:: html

   .. toctree::
      :hidden:
      :maxdepth: 1

      tools/systemtools/index

   .. toctree::
      :maxdepth: 1

      tools/systemtools/Configuration

   .. toctree::
      :maxdepth: 1

      tools/systemtools/AbjadConfiguration
      tools/systemtools/BenchmarkScoreMaker
      tools/systemtools/IOManager
      tools/systemtools/ImportManager
      tools/systemtools/LilyPondFormatBundle
      tools/systemtools/LilyPondFormatManager
      tools/systemtools/RedirectedStreams
      tools/systemtools/StorageFormatManager
      tools/systemtools/StorageFormatSpecification
      tools/systemtools/TestManager
      tools/systemtools/Timer
      tools/systemtools/UpdateManager
      tools/systemtools/WellformednessManager

   .. toctree::
      :maxdepth: 1

      tools/systemtools/requires
      tools/systemtools/run_abjad

.. only:: latex

   Abstract classes
   ----------------

   .. toctree::

      tools/systemtools/Configuration

   Concrete classes
   ----------------

   .. toctree::

      tools/systemtools/AbjadConfiguration
      tools/systemtools/BenchmarkScoreMaker
      tools/systemtools/IOManager
      tools/systemtools/ImportManager
      tools/systemtools/LilyPondFormatBundle
      tools/systemtools/LilyPondFormatManager
      tools/systemtools/RedirectedStreams
      tools/systemtools/StorageFormatManager
      tools/systemtools/StorageFormatSpecification
      tools/systemtools/TestManager
      tools/systemtools/Timer
      tools/systemtools/UpdateManager
      tools/systemtools/WellformednessManager

   Functions
   ---------

   .. toctree::

      tools/systemtools/requires
      tools/systemtools/run_abjad
